package de.intevation.flys.artifacts.model;

import java.util.ArrayList;
import java.util.List;

import org.jfree.chart.annotations.XYTextAnnotation;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.DefaultFacet;

import de.intevation.flys.artifacts.MainValuesArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.jfree.FLYSAnnotation;
import de.intevation.flys.jfree.StickyAxisAnnotation;

/**
 * Facet to show Main W Values.
 */
public class MainValuesWFacet
extends      DefaultFacet
implements   FacetTypes {

    /** Trivial Constructor. */
    public MainValuesWFacet(String description) {
        this.description = description;
        name = COMPUTED_DISCHARGE_MAINVALUES_W;
        index = 0;
    }


    /**
     * Returns the data this facet requires.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext (ignored).
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        MainValuesArtifact mvArtifact = (MainValuesArtifact) artifact;

        List<NamedDouble>      ws = mvArtifact.getMainValuesW();
        List<XYTextAnnotation> xy = new ArrayList<XYTextAnnotation>();

        for (NamedDouble w: ws) {
            xy.add(new StickyAxisAnnotation(
                w.getName(),
                (float) w.getValue(),
                StickyAxisAnnotation.SimpleAxis.Y_AXIS));

        }

        return new FLYSAnnotation(description, xy);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public MainValuesWFacet deepCopy() {
        MainValuesWFacet copy = new MainValuesWFacet(description);
        copy.set(this);
        return copy;
    }
}

